@@ -1,6 +1,6 @@
 import os
 import sys
-from .Channel import *
+# from .Channel import *
 from .Config import *
 from .Core import *
 from .DataProcessing import *
@@ -12,7 +12,7 @@ from .Strategy import *
 sys.modules["ROOT_DIR"] = os.path.abspath(os.path.dirname(__file__))
 
 __all__ = []
-__all__.extend(Channel.__all__)
+# __all__.extend(Channel.__all__)
 __all__.extend(Config.__all__)
 __all__.extend(Core.__all__)
 __all__.extend(DataProcessing.__all__)
